PY_ENVIRONMENT_HELP = """
The path to the virtualenv where your python dependencies for your code are installed
"""
STARTUP_COMMAND_HELP = """
The command you would like to run in order to run 
your code. Put the command in between quotes "gunicorn main:app"
"""

JAVASCRIPT_DIRECTORY_HELP = """
The path to the directory where your javascript code should be stored in a file and run
You can install dependencies and store them in your package.json in that directory
"""

TYPESCRIPT_DIRECTORY_HELP = """
The path to the directory where your typescript code should be stored in a file and run
You can install dependencies and store them in your package.json in that directory
"""

MARKDOWN_PATH_HELP = """
The path to the markdown file you would like to run code from
"""
